BaseHttpLogSender class abstract

Helper base class to handle http errors during network requests.

Inheritance
Implementers

Constructors

BaseHttpLogSender({LogRecordFormatter? formatter, int? bufferSize})

Properties

bufferSize → int
Maximum number of log entries to buffer before triggering sending of log entries. (default: 500)
finalinherited
client → Client
latefinal
formatter → LogRecordFormatter
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userProperties ← Map<String, String>
no getterinherited

Methods

attachToLogger(Logger logger) → void
inherited
call(LogRecord record) → void
inherited
detachFromLoggers() → Future<void>
inherited
dispose() → Future<void>
override
flush() → Future<void>
inherited
handle(LogRecord record) → void
inherited
log(Level logLevel, DateTime time, String line, Map<String, String> lineLabels) → Future<void>
inherited
logListener() → LogRecordListener
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendLogEvents(List<LogEntry> logEntries, Map<String, String> userProperties) → Stream<void>
override
sendLogEventsWithHttp(List<LogEntry> entries, Map<String, String> userProperties, Future<void> cancelToken) → Future<void>
sendRequest(BaseRequest request) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited