HttpLogException class

Implemented types
Available extensions

Constructors

HttpLogException(String message, {Uri? uri, required int statusCode})

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final
uri → Uri?
The URL of the HTTP request or response that failed.
finalinherited

Methods

causedBy(Object chainedException, StackTrace stackTrace) → E

Available on E, provided by the CausedByException extension

Marks this exception as being caused by chainedException.
getCausedByException() → ErrorStack?

Available on E, provided by the CausedByException extension

Retrieves the caused exception for this exception.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStringWithCause() → String

Available on E, provided by the CausedByException extension

calls toString appended by the caused exception, if any.

Operators

operator ==(Object other) → bool
The equality operator.
inherited